@@ -2,31 +2,31 @@ package org.gcube.portlets.user.td.columnwidget.client.batch;
 
 import java.util.ArrayList;
 
-import org.gcube.portlets.user.td.columnwidget.client.progress.ChangeColumnTypeProgressDialog;
-import org.gcube.portlets.user.td.columnwidget.client.progress.ProgressDialogListener;
-import org.gcube.portlets.user.td.columnwidget.client.progress.ReplaceBatchColumnProgressDialog;
-import org.gcube.portlets.user.td.columnwidget.client.progress.ResumeDialogListener;
-import org.gcube.portlets.user.td.columnwidget.client.progress.TaskResumeProgressDialog;
 import org.gcube.portlets.user.td.columnwidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
-import org.gcube.portlets.user.td.gwtservice.shared.Constants;
+import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
+import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
 import org.gcube.portlets.user.td.gwtservice.shared.task.InvocationS;
 import org.gcube.portlets.user.td.gwtservice.shared.task.TaskResumeSession;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.ConditionCode;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.DimensionRow;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.batch.ReplaceBatchColumnSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.batch.ReplaceEntry;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.mapping.ColumnMappingData;
+import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
+import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.ChangeTableRequestEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableRequestType;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableWhy;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.OperationResult;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.RequestProperties;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.RequestPropertiesParameterType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnData;
 
 import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.user.client.rpc.AsyncCallback;
@@ -41,35 +41,39 @@ import com.sencha.gxt.widget.core.client.event.SelectEvent.SelectHandler;
  *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
  * 
  */
-public class ReplaceBatchDialog extends Window implements
-		ProgressDialogListener, ResumeDialogListener {
-	protected String WIDTH = "650px";
-	protected String HEIGHT = "530px";
-	protected TRId trId;
-	protected String columnName = null;
-	protected RequestProperties requestProperties;
-	protected EventBus eventBus;
-	protected String taskId;
+public class ReplaceBatchDialog extends Window implements MonitorDialogListener {
+	// ProgressDialogListener, ResumeDialogListener {
+	protected enum CALLTYPE {
+		REPLACEBATH, RESUME;
+	}
+
+	private static final String WIDTH = "650px";
+	private static final String HEIGHT = "560px";
+	private TRId trId;
+	
+	private EventBus eventBus;
+	private String taskIdOfInvocationS;
+	private CALLTYPE callType;
 	private InvocationS invocationS;
 	private ConditionCode conditionCode; // For Curation
 	
+
 	/**
 	 * 
 	 * @param trId
 	 * @param columnName
 	 * @param eventBus
 	 */
-	public ReplaceBatchDialog(TRId trId, String columnName, EventBus eventBus) {
+	public ReplaceBatchDialog(TRId trId, String columnLocalId, EventBus eventBus) {
 		this.trId = trId;
-		this.columnName = columnName;
 		this.eventBus = eventBus;
-		taskId = null;
+		taskIdOfInvocationS = null;
 		initWindow();
 		ReplaceBatchPanel batchRepalcePanel = new ReplaceBatchPanel(this, trId,
-				columnName, eventBus);
+				columnLocalId, eventBus);
 		add(batchRepalcePanel);
 	}
-	
+
 	/**
 	 * 
 	 * @param trId
@@ -81,24 +85,23 @@ public class ReplaceBatchDialog extends Window implements
 		Log.debug("ReplaceBatchDialog: " + trId + ", RequestProperties:"
 				+ requestProperties);
 		this.trId = trId;
-		this.requestProperties = requestProperties;
 		this.eventBus = eventBus;
 
 		invocationS = (InvocationS) requestProperties.getMap().get(
-				Constants.REQUEST_PROPERTIES_INVOCATIONS);
-		taskId = invocationS.getTaskId();
+				RequestPropertiesParameterType.InvocationS);
+		taskIdOfInvocationS = invocationS.getTaskId();
 
 		conditionCode = (ConditionCode) requestProperties.getMap().get(
-				Constants.REQUEST_PROPERTIES_CONDITIONCODE);
+				RequestPropertiesParameterType.ConditionCode);
 
-		Log.debug("Resume TaskId:" + taskId);
+		Log.debug("Resume TaskId:" + taskIdOfInvocationS);
 		initWindow();
 
 		ReplaceBatchPanel batchRepalcePanel = new ReplaceBatchPanel(this, trId,
 				requestProperties, eventBus);
 		add(batchRepalcePanel);
 	}
-	
+
 	/**
 	 * 
 	 */
@@ -115,7 +118,7 @@ public class ReplaceBatchDialog extends Window implements
 			setHeadingText("Replace Batch");
 			getHeader().setIcon(ResourceBundle.INSTANCE.replaceBatch());
 		} else {
-			switch(conditionCode){
+			switch (conditionCode) {
 			case AllowedColumnType:
 				break;
 			case AmbiguousValueOnExternalReference:
@@ -154,7 +157,7 @@ public class ReplaceBatchDialog extends Window implements
 				setHeadingText("Replace Batch");
 				getHeader().setIcon(ResourceBundle.INSTANCE.replaceBatch());
 				break;
-			
+
 			}
 		}
 	}
@@ -174,7 +177,7 @@ public class ReplaceBatchDialog extends Window implements
 		});
 
 	}
-	
+
 	/**
 	 * 
 	 */
@@ -182,7 +185,7 @@ public class ReplaceBatchDialog extends Window implements
 		hide();
 
 	}
-	
+
 	/**
 	 * 
 	 * @param replaceBatchColumnSession
@@ -234,7 +237,7 @@ public class ReplaceBatchDialog extends Window implements
 			}
 		}
 	}
-	
+
 	/**
 	 * 
 	 * @param replaceBatchColumnSession
@@ -242,224 +245,155 @@ public class ReplaceBatchDialog extends Window implements
 	protected void callStartReplaceBatchColumn(
 			ReplaceBatchColumnSession replaceBatchColumnSession) {
 		TDGWTServiceAsync.INSTANCE.startReplaceBatchColumn(
-				replaceBatchColumnSession, new AsyncCallback<Void>() {
+				replaceBatchColumnSession, new AsyncCallback<String>() {
 
 					public void onFailure(Throwable caught) {
 						if (caught instanceof TDGWTSessionExpiredException) {
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("Start Replace Batch failed:"
-									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error on batch replace",
-									"Error on batch replace");
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("Start Replace Batch failed:"
+											+ caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error on batch replace",
+											"Error on batch replace");
+								}
+							}
 						}
 						close();
 
 					}
 
-					public void onSuccess(Void v) {
+					public void onSuccess(String taskId) {
 						Log.trace("Started batch replace ");
-						callReplaceBatchColumnProgressDialog();
+						callReplaceBatchColumnProgressDialog(taskId);
 
 					}
 
 				});
 	}
-	
+
 	/**
 	 * 
 	 */
-	protected void callReplaceBatchColumnProgressDialog() {
-		ReplaceBatchColumnProgressDialog dialog = new ReplaceBatchColumnProgressDialog(
-				eventBus);
-		dialog.addProgressDialogListener(this);
-		dialog.show();
+	// TODO
+	protected void callReplaceBatchColumnProgressDialog(String taskId) {
+		callType = CALLTYPE.REPLACEBATH;
+		openMonitorDialog(taskId);
 
 	}
 
-	@Override
-	public void operationComplete(TRId trId) {
-		this.trId = trId;
-		if (taskId == null) {
-			ChangeTableWhy why = ChangeTableWhy.TABLEUPDATED;
-			ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-					ChangeTableRequestType.COLUMNREPLACEBATCH, trId, why);
-			eventBus.fireEvent(changeTableRequestEvent);
-			hide();
-		} else {
-			if (conditionCode == null) {
-				startTaskResume();
-			} else {
-				switch (conditionCode) {
-				case AllowedColumnType:
-					break;
-				case AmbiguousValueOnExternalReference:
-					ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
-					ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-							ChangeTableRequestType.COLUMNREPLACEBATCH, trId,
-							why);
-					eventBus.fireEvent(changeTableRequestEvent);
-					hide();
-					break;
-				case CastValidation:
-					break;
-				case CodeNamePresence:
-					break;
-				case DuplicateTupleValidation:
-					break;
-				case DuplicateValueInColumn:
-					break;
-				case GenericTupleValidity:
-					break;
-				case GenericValidity:
-					break;
-				case MaxOneCodenameForDataLocale:
-					break;
-				case MissingValueOnExternalReference:
-					startTaskResume();
-					break;
-				case MustContainAtLeastOneDimension:
-					break;
-				case MustContainAtLeastOneMeasure:
-					break;
-				case MustHaveDataLocaleMetadataAndAtLeastOneLabel:
-					break;
-				case OnlyOneCodeColumn:
-					break;
-				case OnlyOneCodenameColumn:
-					break;
-				case ValidPeriodFormat:
-					break;
-				default:
-					startTaskResume();
-					break;
-
-				}
-			}
-
-		}
-
-	}
-
-	@Override
-	public void operationFailed(Throwable caught, String reason) {
-		UtilsGXT3.alert("Error in Replace Batch", reason);
-		hide();
-	}
-
-	@Override
-	public void operationStopped(TRId trId, String reason, String details) {
-		ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
-		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-				ChangeTableRequestType.COLUMNREPLACEBATCH, trId, why);
-		eventBus.fireEvent(changeTableRequestEvent);
-		hide();
-
-	}
-	
 	/**
 	 * 
 	 */
 	protected void startTaskResume() {
 		TaskResumeSession taskResumeSession = new TaskResumeSession(trId,
-				taskId);
+				taskIdOfInvocationS);
 		TDGWTServiceAsync.INSTANCE.startTaskResume(taskResumeSession,
-				new AsyncCallback<Void>() {
+				new AsyncCallback<String>() {
 
 					public void onFailure(Throwable caught) {
 						if (caught instanceof TDGWTSessionExpiredException) {
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("Task Resume failed:"
-									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error on task resume",
-									"Error on task resume (taskId=" + taskId
-											+ ")");
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("Task Resume failed:"
+											+ caught.getLocalizedMessage());
+									UtilsGXT3
+											.alert("Error on task resume",
+													"Error on task resume (taskId="
+															+ taskIdOfInvocationS
+															+ ")");
+								}
+							}
 						}
 						close();
 
 					}
 
-					public void onSuccess(Void v) {
+					public void onSuccess(String taskId) {
 						Log.trace("Started task resume");
-						callForTaskResume();
+						callForTaskResume(taskId);
 
 					}
 
 				});
 	}
-	
+
 	/**
 	 * 
 	 * @param mapping
 	 */
-	protected void startTaskResume(ArrayList<ColumnMappingData> mapping, ColumnData column) {
+	protected void startTaskResume(ArrayList<ColumnMappingData> mapping,
+			ColumnData column) {
 		TaskResumeSession taskResumeSession = new TaskResumeSession(trId,
-				taskId, mapping, column, invocationS);
+				taskIdOfInvocationS, mapping, column, invocationS);
 		TDGWTServiceAsync.INSTANCE.startTaskResume(taskResumeSession,
-				new AsyncCallback<Void>() {
+				new AsyncCallback<String>() {
 
 					public void onFailure(Throwable caught) {
 						if (caught instanceof TDGWTSessionExpiredException) {
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("Task Resume failed:"
-									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error on task resume",
-									"Error on task resume (taskId=" + taskId
-											+ ")");
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("Task Resume failed:"
+											+ caught.getLocalizedMessage());
+									UtilsGXT3
+											.alert("Error on task resume",
+													"Error on task resume (taskId="
+															+ taskIdOfInvocationS
+															+ ")");
+								}
+							}
 						}
 						close();
 
 					}
 
-					public void onSuccess(Void v) {
+					public void onSuccess(String taskId) {
 						Log.trace("Started task resume");
-						callForTaskResume();
+						callForTaskResume(taskId);
 
 					}
 
 				});
 	}
-	
-	
+
 	/**
 	 * 
 	 */
-	protected void callForTaskResume() {
-		TaskResumeProgressDialog dialog = new TaskResumeProgressDialog(eventBus);
-		dialog.addResumeDialogListener(this);
-		dialog.show();
-
-	}
-
-	@Override
-	public void resumeComplete(TRId trId) {
-		ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
-		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-				ChangeTableRequestType.COLUMNREPLACEBATCH, trId, why);
-		eventBus.fireEvent(changeTableRequestEvent);
-		hide();
-
-	}
-
-	@Override
-	public void resumeFailed(Throwable caught, String reason) {
-		UtilsGXT3.alert("Error in Task Resume", reason);
-		hide();
-
-	}
-
-	@Override
-	public void resumeStopped(TRId trId, String reason, String details) {
-		ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
-		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-				ChangeTableRequestType.COLUMNREPLACEBATCH, trId, why);
-		eventBus.fireEvent(changeTableRequestEvent);
-		hide();
+	protected void callForTaskResume(String taskId) {
+		callType = CALLTYPE.RESUME;
+		openMonitorDialog(taskId);
 
 	}
 
@@ -469,10 +403,11 @@ public class ReplaceBatchDialog extends Window implements
 	 */
 	private void callResumeOnChangeColumnType(
 			ReplaceBatchColumnSession replaceBatchColumnSession) {
-		Log.debug("ReplaceBatchColumnSession: "+replaceBatchColumnSession.toString());
-		
-		ColumnData col=replaceBatchColumnSession.getColumnData();
-		
+		Log.debug("ReplaceBatchColumnSession: "
+				+ replaceBatchColumnSession.toString());
+
+		ColumnData col = replaceBatchColumnSession.getColumnData();
+
 		ArrayList<ReplaceEntry> replaceEntryList = replaceBatchColumnSession
 				.getReplaceEntryList();
 		ArrayList<ColumnMappingData> mapping = new ArrayList<ColumnMappingData>();
@@ -485,19 +420,142 @@ public class ReplaceBatchDialog extends Window implements
 					sourceArg, targetArg);
 			mapping.add(columnMappingData);
 		}
-		
+
 		startTaskResume(mapping, col);
 
 	}
 
 	/**
 	 * 
+	 protected void callChangeColumnTypeProgressDialog() {
+	 * ChangeColumnTypeProgressDialog changeColumnTypeProgressDialog = new
+	 * ChangeColumnTypeProgressDialog( eventBus);
+	 * changeColumnTypeProgressDialog.addProgressDialogListener(this);
+	 * changeColumnTypeProgressDialog.show(); }
 	 */
-	protected void callChangeColumnTypeProgressDialog() {
-		ChangeColumnTypeProgressDialog changeColumnTypeProgressDialog = new ChangeColumnTypeProgressDialog(
-				eventBus);
-		changeColumnTypeProgressDialog.addProgressDialogListener(this);
-		changeColumnTypeProgressDialog.show();
+
+	// /
+	protected void openMonitorDialog(String taskId) {
+		MonitorDialog monitorDialog = new MonitorDialog(taskId, eventBus);
+		monitorDialog.addProgressDialogListener(this);
+		monitorDialog.setBackgroundBtnEnabled(false);
+		monitorDialog.show();
+	}
+
+	@Override
+	public void operationComplete(OperationResult operationResult) {
+		switch (callType) {
+		case REPLACEBATH:
+			this.trId = operationResult.getTrId();
+			if (taskIdOfInvocationS == null) {
+				ChangeTableWhy why = ChangeTableWhy.TABLEUPDATED;
+				ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
+						ChangeTableRequestType.COLUMNREPLACEBATCH, trId, why);
+				eventBus.fireEvent(changeTableRequestEvent);
+				close();
+			} else {
+				if (conditionCode == null) {
+					startTaskResume();
+				} else {
+					switch (conditionCode) {
+					case AllowedColumnType:
+						break;
+					case AmbiguousValueOnExternalReference:
+						ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
+						ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
+								ChangeTableRequestType.COLUMNREPLACEBATCH,
+								trId, why);
+						eventBus.fireEvent(changeTableRequestEvent);
+						close();
+						break;
+					case CastValidation:
+						break;
+					case CodeNamePresence:
+						break;
+					case DuplicateTupleValidation:
+						break;
+					case DuplicateValueInColumn:
+						break;
+					case GenericTupleValidity:
+						break;
+					case GenericValidity:
+						break;
+					case MaxOneCodenameForDataLocale:
+						break;
+					case MissingValueOnExternalReference:
+						startTaskResume();
+						break;
+					case MustContainAtLeastOneDimension:
+						break;
+					case MustContainAtLeastOneMeasure:
+						break;
+					case MustHaveDataLocaleMetadataAndAtLeastOneLabel:
+						break;
+					case OnlyOneCodeColumn:
+						break;
+					case OnlyOneCodenameColumn:
+						break;
+					case ValidPeriodFormat:
+						break;
+					default:
+						startTaskResume();
+						break;
+
+					}
+				}
+
+			}
+			break;
+		case RESUME:
+			ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
+			ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
+					ChangeTableRequestType.COLUMNREPLACEBATCH, operationResult.getTrId(), why);
+			eventBus.fireEvent(changeTableRequestEvent);
+			hide();
+			break;
+		default:
+			break;
+
+		}
+
+	}
+
+	@Override
+	public void operationFailed(Throwable caught, String reason, String details) {
+		switch (callType) {
+		case REPLACEBATH:
+			UtilsGXT3.alert("Error in Replace Batch", reason);
+			close();
+			break;
+		case RESUME:
+			UtilsGXT3.alert("Error in Task Resume", reason);
+			hide();
+			break;
+		default:
+			break;
+		}
+	}
+
+	@Override
+	public void operationStopped(OperationResult operationResult, String reason, String details) {
+		ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
+		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
+				ChangeTableRequestType.COLUMNREPLACEBATCH, operationResult.getTrId(), why);
+		eventBus.fireEvent(changeTableRequestEvent);
+		close();
+
+	}
+
+	@Override
+	public void operationAborted() {
+		close();
+
+	}
+
+	@Override
+	public void operationPutInBackground() {
+		close();
+
 	}
 
 }
