@@ -2,9 +2,9 @@ package org.gcube.portlets.user.td.columnwidget.client.dimension;
 
 import java.util.ArrayList;
 
-import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataPropertiesCombo;
 import org.gcube.portlets.user.td.columnwidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataPropertiesCombo;
 import org.gcube.portlets.user.td.expressionwidget.client.properties.TabResourceProperties;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
